<a href="https://www.islas.org.mx/"><img src="https://www.islas.org.mx/img/logo.svg" align="right" width="256" /></a>
# Test tools
[![codecov](https://codecov.io/gh/IslasGECI/test_tools/graph/badge.svg?token=v0yYwY2WjO)](https://codecov.io/gh/IslasGECI/test_tools)
![licencia](https://img.shields.io/github/license/IslasGECI/test_tools)
![languages](https://img.shields.io/github/languages/top/IslasGECI/test_tools)
![commits](https://img.shields.io/github/commit-activity/y/IslasGECI/test_tools)
![PyPI - Version](https://img.shields.io/pypi/v/test_tools)

## Install
```
pip install geci_test_tools
```

### Functions
- `if_exist_remove()`
- `calculate_hash()`
- `assert_not_exist()`
- `assert_exist()`